#These are the functions that need to be imported inorder to make all this work.
#These imported functions is where the 'magic' happens
from plsa.preprocessors import *
from plsa.pipeline import Pipeline
from plsa.corpus import Corpus
from plsa.algorithms.plsa import PLSA
from plsa.visualize import Visualize
from matplotlib.figure import Figure
from matplotlib.axes import Axes
from matplotlib import pyplot as plt 

# A textFile containing all the text from both websites broken up by html element
textFile = open('example.txt','r').read()

#splitting the textfile into seperate "strings of text"
documents = textFile.split('\n')

# removes all words less than 3 in length
gt_two = remove_short_words(3)  

#removes all specified punctiation
no_punct = remove_punctuation([',', '.', '-', '(', ')', '?', '<', '>', ';', ':', '$', '%'])  

# Saves only nouns (NN), verbs (VB), adjectives (JJ) or adverbs (RB)
lemmatizer = LemmatizeWords('NN')  
lemmatizer += 'JJ'

# removes any word that is put into function
remover = RemoveStopwords('is')  
remover.words = ('is', 'the', 'it', 'on', 'a', 'an')

# This will automate sending the textFile through all of the above functions
pipe = Pipeline(to_lower, remove_non_ascii, remove_numbers, no_punct, tokenize, gt_two, remover, lemmatizer)  
corpus = Corpus(documents, pipe)

# Running the algorithm
model = PLSA(corpus, 6, False)  
result = model.fit()


# This code will print some of the results
topics = result.word_given_topic
print(topics[0])
for word in topics:
	print(word[0])

#Code to show a wordcloud of the analyzed data from the result
visualizer = Visualize(result)
fig, ax = plt.subplots()
ax.bar = visualizer.wordclouds(fig)
plt.show()